Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GenerateApiKeyResponse ¶ added in v1.25.0
type GenerateApiKeyResponse interface {
// contains filtered or unexported methods
}
GenerateApiKeyResponse is the base response type for a generate api key request.
type GenerateApiKeySuccess ¶ added in v1.25.0
type GenerateApiKeySuccess struct {
ApiKey string
RefreshToken string
Endpoint string
ExpiresAt utils.ExpiresAt
}
GenerateApiKeySuccess indicates a successful generate api key request.
type GenerateDisposableTokenResponse ¶
type GenerateDisposableTokenResponse interface {
// contains filtered or unexported methods
}
GenerateDisposableTokenResponse is the base response type for a generate disposable token request.
type GenerateDisposableTokenSuccess ¶
GenerateDisposableTokenSuccess indicates a successful generate disposable token request.
type RefreshApiKeyResponse ¶ added in v1.26.0
type RefreshApiKeyResponse interface {
// contains filtered or unexported methods
}
RefreshApiKeyResponse is the base response type for a refresh api key request.
Click to show internal directories.
Click to hide internal directories.